@@ -2,7 +2,7 @@ use super::{CommandBorrowed, InteractionError, InteractionErrorType};
 use crate::{
     client::Client,
     error::Error as HttpError,
-    request::{validate, Request, RequestBuilder},
+    request::{validate_inner, Request, RequestBuilder},
     response::ResponseFuture,
     routing::Route,
 };
@@ -38,13 +38,13 @@ impl<'a> CreateGuildCommand<'a> {
         name: &'a str,
         description: &'a str,
     ) -> Result<Self, InteractionError> {
-        if !validate::command_name(name) {
+        if !validate_inner::command_name(&name) {
             return Err(InteractionError {
                 kind: InteractionErrorType::CommandNameValidationFailed,
             });
         }
 
-        if !validate::command_description(description) {
+        if !validate_inner::command_description(&description) {
             return Err(InteractionError {
                 kind: InteractionErrorType::CommandDescriptionValidationFailed,
             });
