@@ -12,7 +12,13 @@ mod get_gateway_authed;
 mod get_user_application;
 mod get_voice_regions;
 mod multipart;
-mod validate;
+
+// Rename this module so we can expose a select amount of validation types.
+//
+// Work to prepare the validation module will need to be done individually, so
+// for now only a select number of types are exposed until prepared.
+#[path = "validate.rs"]
+mod validate_inner;
 
 pub use self::{
     audit_reason::{AuditLogReason, AuditLogReasonError},
